summaryrefslogtreecommitdiffstats
path: root/ksysv/ksvpathconfig.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'ksysv/ksvpathconfig.cpp')
-rw-r--r--ksysv/ksvpathconfig.cpp6
1 files changed, 3 insertions, 3 deletions
diff --git a/ksysv/ksvpathconfig.cpp b/ksysv/ksvpathconfig.cpp
index f7e5f52..5f1193a 100644
--- a/ksysv/ksvpathconfig.cpp
+++ b/ksysv/ksvpathconfig.cpp
@@ -29,11 +29,11 @@
#include <kfiledialog.h>
/*
* Constructs a KSVPathConfig which is a child of 'tqparent', with the
* name 'name' and widget flags set to 'f'
*/
-KSVPathConfig::KSVPathConfig( TQWidget* tqparent, const char* name, WFlags fl )
- : PathConfiguration( tqparent, name, fl )
+KSVPathConfig::KSVPathConfig( TQWidget* parent, const char* name, WFlags fl )
+ : PathConfiguration( parent, name, fl )
{
mSpacer->setFixedHeight (KDialog::spacingHint());
}
@@ -29,11 +29,11 @@
#include <kfiledialog.h>
/*
- * Constructs a KSVPathConfig which is a child of 'tqparent', with the
+ * Constructs a KSVPathConfig which is a child of 'parent', with the
* name 'name' and widget flags set to 'f'
*/